@@ -1,6 +1,8 @@
 from django.contrib import admin
 
-from .models import ImportSetup, ImportSetupAction, ImportSetupItem
+from .models import (
+    ImportSetup, ImportSetupAction, ImportSetupItem, ImportSetupLog
+)
 
 
 class ImportSetupItemInline(admin.StackedInline):
@@ -17,9 +19,18 @@ class ImportSetupActionInline(admin.StackedInline):
     allow_add = True
 
 
+class ImportSetupLogInline(admin.StackedInline):
+    model = ImportSetupLog
+    extra = 1
+    classes = ('collapse-open',)
+    allow_add = True
+
+
 @admin.register(ImportSetup)
 class ImportSetupAdmin(admin.ModelAdmin):
-    inlines = (ImportSetupActionInline, ImportSetupItemInline,)
+    inlines = (
+        ImportSetupActionInline, ImportSetupLogInline, ImportSetupItemInline,
+    )
     list_display = (
         'label', 'document_type', 'credential', 'process_size'
     )
