@@ -12,7 +12,7 @@ from django.utils.translation import ugettext_lazy as _
 from mayan.apps.common.models import SharedUploadedFile
 from mayan.apps.storage.utils import NamedTemporaryFile
 
-from credentials.credentials import OAuthAccessToken
+from credentials.credential_backends import OAuthAccessToken
 
 from .classes import ImportSetupBackend
 
