@@ -10,7 +10,6 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.documents.models.document_models import Document
 from mayan.apps.documents.models.document_type_models import DocumentType
-from mayan.apps.documents.tasks import task_upload_new_version
 from mayan.apps.events.classes import (
     EventManagerMethodAfter, EventManagerSave
 )
@@ -21,7 +20,9 @@ from credentials.models import StoredCredential
 from .classes import NullBackend
 from .events import (
     event_import_setup_created, event_import_setup_edited,
-    event_import_setup_processed, event_import_setup_item_completed
+    event_import_setup_populate_ended, event_import_setup_populate_started,
+    event_import_setup_process_ended, event_import_setup_process_started,
+    event_import_setup_item_completed
 )
 from .literals import (
     DEFAULT_PROCESS_SIZE, ITEM_STATE_CHOICES, ITEM_STATE_COMPLETE,
@@ -38,13 +39,16 @@ IMPORT_ERROR_EXCLUSION_TEXTS = (
 
 
 class BackendModelMixin(models.Model):
+    # TODO: Use common.model_mixins.BackendModelMixin after upgrade to version
+    # 4.0.
     backend_path = models.CharField(
         max_length=128,
         help_text=_('The dotted Python path to the backend class.'),
         verbose_name=_('Backend path')
     )
     backend_data = models.TextField(
-        blank=True, verbose_name=_('Backend data')
+        blank=True, help_text=_('JSON encoded data for the backend class.'),
+        verbose_name=_('Backend data')
     )
 
     class Meta:
@@ -106,7 +110,7 @@ class ImportSetup(BackendModelMixin, models.Model):
     process_size = models.PositiveIntegerField(
         default=DEFAULT_PROCESS_SIZE, help_text=_(
             'Number of items to process per execution.'
-        ), verbose_name=_('Process size.')
+        ), verbose_name=_('Process size')
     )
     state = models.PositiveIntegerField(
         choices=SETUP_STATE_CHOICES, default=SETUP_STATE_NONE, help_text=_(
@@ -172,7 +176,11 @@ class ImportSetup(BackendModelMixin, models.Model):
 
     item_count_percent.short_description = _('Progress')
 
-    def populate(self):
+    def populate(self, user=None):
+        event_import_setup_populate_started.commit(
+            actor=user, target=self
+        )
+
         if ENABLE_STATE_CHANGE:
             self.state = SETUP_STATE_POPULATING
             self.save()
@@ -198,11 +206,15 @@ class ImportSetup(BackendModelMixin, models.Model):
                         obj=item
                     )
                     setup_item.save()
-        except Exception:
+        except Exception as exception:
             if ENABLE_STATE_CHANGE:
                 self.state = SETUP_STATE_ERROR
                 self.save()
 
+            self.logs.create(
+                text=str(exception)
+            )
+
             if settings.DEBUG:
                 raise
         else:
@@ -210,12 +222,13 @@ class ImportSetup(BackendModelMixin, models.Model):
                 self.state = SETUP_STATE_NONE
                 self.save()
 
-    @method_event(
-        event_manager_class=EventManagerMethodAfter,
-        event=event_import_setup_processed,
-        target='self',
-    )
-    def process(self):
+            event_import_setup_populate_ended.commit(
+                actor=user, target=self
+            )
+
+            self.logs.all().delete()
+
+    def process(self, user=None):
         """
         Iterate of the ImportSetupItem instances downloading and creating
         documents from them.
@@ -224,6 +237,10 @@ class ImportSetup(BackendModelMixin, models.Model):
             self.state = SETUP_STATE_EXECUTING
             self.save()
 
+        event_import_setup_process_started.commit(
+            actor=user, target=self
+        )
+
         count = 0
         try:
             queryset = self.items.filter(state=ITEM_STATE_NONE)
@@ -240,17 +257,36 @@ class ImportSetup(BackendModelMixin, models.Model):
                     )
                     if count >= self.process_size:
                         break
-        except Exception:
+        except StopIteration:
+            """
+            Expected exception when iterator is exhausted before the process
+            size is reached.
+            """
+        except Exception as exception:
             if ENABLE_STATE_CHANGE:
                 self.state = SETUP_STATE_ERROR
                 self.save()
 
+            self.logs.create(
+                text=str(exception)
+            )
+
             if settings.DEBUG:
                 raise
-        else:
-            if ENABLE_STATE_CHANGE:
-                self.state = SETUP_STATE_NONE
-                self.save()
+
+            # Exit the method to avoid committing the ended event.
+            return
+
+        # This line is reached on StopIteration or from the break in the loop.
+        if ENABLE_STATE_CHANGE:
+            self.state = SETUP_STATE_NONE
+            self.save()
+
+        self.logs.all().delete()
+
+        event_import_setup_process_ended.commit(
+            actor=user, target=self
+        )
 
     @method_event(
         event_manager_class=EventManagerSave,
@@ -286,7 +322,9 @@ class ImportSetupAction(BackendModelMixin, models.Model):
 
     class Meta:
         ordering = ('order', 'label')
-        unique_together = (('import_setup', 'order'), ('import_setup', 'label'))
+        unique_together = (
+            ('import_setup', 'order'), ('import_setup', 'label')
+        )
         verbose_name = _('Import setup action')
         verbose_name_plural = _('Import setup actions')
 
@@ -352,8 +390,8 @@ class ImportSetupItem(models.Model):
     @method_event(
         event_manager_class=EventManagerMethodAfter,
         event=event_import_setup_item_completed,
-        action_object='self',
-        target='import_setup',
+        action_object='import_setup',
+        target='self',
     )
     def create_document(self, shared_uploaded_file):
         """
@@ -448,4 +486,24 @@ class ImportSetupItem(models.Model):
 
                     context = {'document': document, 'self': self}
                     for action in self.import_setup.actions.filter(enabled=True):
-                        action.execute(context=contex)
+                        action.execute(context=context)
+
+
+class ImportSetupLog(models.Model):
+    import_setup = models.ForeignKey(
+        on_delete=models.CASCADE, related_name='logs',
+        to=ImportSetup, verbose_name=_('Import setup log')
+    )
+    datetime = models.DateTimeField(
+        auto_now_add=True, db_index=True, editable=False,
+        verbose_name=_('Date time')
+    )
+    text = models.TextField(
+        blank=True, editable=False, verbose_name=_('Text')
+    )
+
+    class Meta:
+        get_latest_by = 'datetime'
+        ordering = ('-datetime',)
+        verbose_name = _('Log entry')
+        verbose_name_plural = _('Log entries')
